@@ -28,7 +28,28 @@
 #include <sys/types.h>
 #include <string.h>
 
-#define TEST_FILE(name) (SRCDIR "/files/" name)
+static const gchar *
+tls_test_file_path (const char *name)
+{
+  const gchar *const_path;
+  gchar *path;
+
+  path = g_test_build_filename (G_TEST_DIST, "files", name, NULL);
+  if (!g_path_is_absolute (path))
+    {
+      gchar *cwd, *abs;
+
+      cwd = g_get_current_dir ();
+      abs = g_build_filename (cwd, path, NULL);
+      g_free (cwd);
+      g_free (path);
+      path = abs;
+    }
+
+  const_path = g_intern_string (path);
+  g_free (path);
+  return const_path;
+}
 
 /* -----------------------------------------------------------------------------
  * CERTIFICATE VERIFY
@@ -46,13 +67,13 @@ setup_verify (TestVerify     *test,
 {
   GError *error = NULL;
 
-  test->cert = g_tls_certificate_new_from_file (TEST_FILE ("server.pem"), &error);
+  test->cert = g_tls_certificate_new_from_file (tls_test_file_path ("server.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (test->cert));
 
   test->identity = g_network_address_new ("server.example.com", 80);
 
-  test->database = g_tls_file_database_new (TEST_FILE ("ca.pem"), &error);
+  test->database = g_tls_file_database_new (tls_test_file_path ("ca.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_DATABASE (test->database));
 }
@@ -126,7 +147,7 @@ test_verify_database_bad_ca (TestVerify      *test,
   GError *error = NULL;
 
   /* Use another certificate which isn't in our CA list */
-  cert = g_tls_certificate_new_from_file (TEST_FILE ("server-self.pem"), &error);
+  cert = g_tls_certificate_new_from_file (tls_test_file_path ("server-self.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (cert));
 
@@ -148,7 +169,7 @@ test_verify_database_bad_before (TestVerify      *test,
   GError *error = NULL;
 
   /* This is a certificate in the future */
-  cert = g_tls_certificate_new_from_file (TEST_FILE ("client-future.pem"), &error);
+  cert = g_tls_certificate_new_from_file (tls_test_file_path ("client-future.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (cert));
 
@@ -170,7 +191,7 @@ test_verify_database_bad_expired (TestVerify      *test,
   GError *error = NULL;
 
   /* This is a certificate in the future */
-  cert = g_tls_certificate_new_from_file (TEST_FILE ("client-past.pem"), &error);
+  cert = g_tls_certificate_new_from_file (tls_test_file_path ("client-past.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (cert));
 
@@ -192,7 +213,7 @@ test_verify_database_bad_combo (TestVerify      *test,
   GTlsCertificateFlags errors;
   GError *error = NULL;
 
-  cert = g_tls_certificate_new_from_file (TEST_FILE ("server-self.pem"), &error);
+  cert = g_tls_certificate_new_from_file (tls_test_file_path ("server-self.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (cert));
 
@@ -272,11 +293,11 @@ test_verify_with_incorrect_root_in_chain (void)
    * This database contains a single anchor certificate of:
    * C = US, O = "VeriSign, Inc.", OU = Class 3 Public Primary Certification Authority
    */
-  database = g_tls_file_database_new (TEST_FILE ("ca-verisign-sha1.pem"), &error);
+  database = g_tls_file_database_new (tls_test_file_path ("ca-verisign-sha1.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_DATABASE (database));
 
-  ca_verisign_sha1 = g_tls_certificate_new_from_file (TEST_FILE ("ca-verisign-sha1.pem"), &error);
+  ca_verisign_sha1 = g_tls_certificate_new_from_file (tls_test_file_path ("ca-verisign-sha1.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (ca_verisign_sha1));
 
@@ -288,7 +309,7 @@ test_verify_with_incorrect_root_in_chain (void)
    * verify this chain as valid, since the issuer fields and signatures should chain up
    * to the certificate in our database.
    */
-  chain = load_certificate_chain (TEST_FILE ("chain-with-verisign-md2.pem"), &error);
+  chain = load_certificate_chain (tls_test_file_path ("chain-with-verisign-md2.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (chain));
 
@@ -328,7 +349,7 @@ setup_file_database (TestFileDatabase *test,
 {
   GError *error = NULL;
 
-  test->path = TEST_FILE ("ca-roots.pem");
+  test->path = tls_test_file_path ("ca-roots.pem");
   test->database = g_tls_file_database_new (test->path, &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_DATABASE (test->database));
@@ -360,7 +381,7 @@ test_file_database_handle (TestFileDatabase *test,
    * is 'in' the database.
    */
 
-  certificate = g_tls_certificate_new_from_file (TEST_FILE ("ca.pem"), &error);
+  certificate = g_tls_certificate_new_from_file (tls_test_file_path ("ca.pem"), &error);
   g_assert_no_error (error);
   g_assert (G_IS_TLS_CERTIFICATE (certificate));
 
@@ -404,11 +425,11 @@ test_anchors_property (void)
   gchar *anchor_filename = NULL;
   GError *error = NULL;
 
-  database = g_tls_file_database_new (TEST_FILE ("ca.pem"), &error);
+  database = g_tls_file_database_new (tls_test_file_path ("ca.pem"), &error);
   g_assert_no_error (error);
 
   g_object_get (database, "anchors", &anchor_filename, NULL);
-  g_assert_cmpstr (anchor_filename, ==, TEST_FILE ("ca.pem"));
+  g_assert_cmpstr (anchor_filename, ==, tls_test_file_path ("ca.pem"));
   g_free (anchor_filename);
 
   g_object_unref (database);
@@ -457,7 +478,7 @@ test_lookup_certificates_issued_by (void)
   GTlsDatabase *database;
   GError *error = NULL;
 
-  database = g_tls_file_database_new (TEST_FILE ("non-ca.pem"), &error);
+  database = g_tls_file_database_new (tls_test_file_path ("non-ca.pem"), &error);
   g_assert_no_error (error);
 
   issuer_dn = g_byte_array_new ();
@@ -472,11 +493,11 @@ test_lookup_certificates_issued_by (void)
 
   g_assert_cmpuint (g_list_length (certificates), ==, 4);
 
-  g_assert (certificate_is_in_list (certificates, TEST_FILE ("client.pem")));
-  g_assert (certificate_is_in_list (certificates, TEST_FILE ("client-future.pem")));
-  g_assert (certificate_is_in_list (certificates, TEST_FILE ("client-past.pem")));
-  g_assert (certificate_is_in_list (certificates, TEST_FILE ("server.pem")));
-  g_assert (!certificate_is_in_list (certificates, TEST_FILE ("server-self.pem")));
+  g_assert (certificate_is_in_list (certificates, tls_test_file_path ("client.pem")));
+  g_assert (certificate_is_in_list (certificates, tls_test_file_path ("client-future.pem")));
+  g_assert (certificate_is_in_list (certificates, tls_test_file_path ("client-past.pem")));
+  g_assert (certificate_is_in_list (certificates, tls_test_file_path ("server.pem")));
+  g_assert (!certificate_is_in_list (certificates, tls_test_file_path ("server-self.pem")));
 
   g_list_free_full (certificates, g_object_unref);
   g_object_unref (database);
